==> onthefly-1.0.3.tar.gz: onthefly-1.0.3/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=7.0', 'evdev', 'appdirs', 'elevate']

setup_requirements = [ ]

test_requirements = [ ]

setup(
    author="Martin Roa Villescas",
    author_email='mroavi@gmail.com',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="Code like a god on-the-fly",
    entry_points={
        'console_scripts': [
            'onthefly=onthefly.cli:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='onthefly',
    name='onthefly',
    packages=find_packages(include=['onthefly', 'onthefly.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/mroavi/onthefly',
    version='1.0.3',
    zip_safe=False,
)

==> onthefly-1.0.8.tar.gz: onthefly-1.0.8/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.md') as readme_file:
    readme = readme_file.read()

requirements = ['Click>=7.0', 'evdev', 'appdirs', 'elevate']

setup_requirements = [ ]

test_requirements = [ ]

setup(
    author="Martin Roa Villescas",
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ],
    description="Type like a god on-the-fly",
    entry_points={
        'console_scripts': [
            'onthefly=onthefly.cli:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme,
    long_description_content_type='text/markdown',
    include_package_data=True,
    keywords='onthefly',
    name='onthefly',
    packages=find_packages(include=['onthefly', 'onthefly.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/mroavi/onthefly',
    version='1.0.8',
    zip_safe=False,
)
